@@ -37,7 +37,8 @@ from imecilabt.gpulab.model.job2 import Job as Job2, JobStatus, JobPortMapping a
 from imecilabt.gpulab.model.slave_info2 import SlaveInfo2
 
 from imecilabt.gpulab.cli.apiclient import GpuLabApiClient, JOB_DEFINITION, BadPemPasswordException, \
-    GPULAB_LOCALHOST_MODE, GpuLabApiLocalhostModeClient, GpuLabAnonymousApiClient
+    GPULAB_LOCALHOST_MODE, GpuLabApiLocalhostModeClient, GpuLabAnonymousApiClient, CertExpiredException, \
+    LegacyAuthException
 
 import datetime
 import click
@@ -188,7 +189,7 @@ def _port_mapping_format(port_mappings: List[Job2PortMapping]) -> str:
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-GPULAB_VERSION = '3.6.0'
+GPULAB_VERSION = '3.7.0'
 
 
 def check_and_warn_version(ctx):
@@ -346,7 +347,7 @@ def modify_usage_error():
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def cli(ctx: click.Context, cert, password, deployment_environment: str, servercert, debug, custom_master_url):
-    """GPULab client version 3.6.0
+    """GPULab client version 3.7.0
 
     \b
     This is the general help. For help with a specific command, try:
@@ -399,9 +400,25 @@ def cli(ctx: click.Context, cert, password, deployment_environment: str, serverc
         click.echo(cli.get_help(ctx))
 
     def make_api_client(ctx):
-        ctx.obj[API_CLIENT] = GpuLabApiClient(certfile=cert, keyfile=cert, password=password, dev=is_staging,
-                                              server_self_signed_cert=servercert,
-                                              master_base_url=master_base_url)
+        try:
+            ctx.obj[API_CLIENT] = GpuLabApiClient(certfile=cert, keyfile=cert, password=password, dev=is_staging,
+                                                  server_self_signed_cert=servercert,
+                                                  master_base_url=master_base_url)
+        except CertExpiredException as e:
+            raise click.ClickException(
+                f'The certificate in your login PEM has expired. \n'
+                f'Re-download it from the portal to get an up to date one. \nCertificate details: \n'
+                f'   not_valid_before={e.not_valid_before} \n'
+                f'   not_valid_after={e.not_valid_after} \n'
+                f'   user_urn={e.user_urn}')
+        except LegacyAuthException as e:
+            raise click.ClickException(
+                f'You are using a login PEM from the legacy wall2 authority ({cert}). \n'
+                f'This is no longer supported. \n\n'
+                f'You need to use an account from '
+                f'https://account.ilabt.imec.be/ or https://portal.fed4fire.eu/ to continue using GPULab.\n\n'
+                f'Contact support if you need help migrating your account: gpulab@ilabt.imec.be'
+            )
 
     def make_anon_api_client(ctx):
         ctx.obj[API_CLIENT] = GpuLabAnonymousApiClient(server_self_signed_cert=servercert, master_base_url=master_base_url)
@@ -585,7 +602,7 @@ def print_bugreport_context(ctx):
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def localhost_mode_cli(ctx):
-    """GPULab client version 3.6.0 (in LOCALHOST_MODE!)
+    """GPULab client version 3.7.0 (in LOCALHOST_MODE!)
 
     \b
     Send bugreports, questions and feedback to: gpulab@ilabt.imec.be
@@ -738,7 +755,7 @@ def run_interactive(ctx, project, duration_minutes, docker_image, proxy, ssh_pub
             "docker": {
                 "image": docker_image,
                 "command": command,
-                "storage": [{"containerPath": "/project"}]
+                "storage": [{"mountPath": "PROJECT_SHARE_AUTO", "containerPath": "/project"}]
             },
             "resources": {
                 "clusterId": cluster_id,  # None is fine here
