@@ -39,6 +39,17 @@ class BadPemPasswordException(Exception):
     pass
 
 
+class LegacyAuthException(Exception):
+    pass
+
+
+class CertExpiredException(Exception):
+    def __init__(self, *, not_valid_after, not_valid_before, user_urn):
+        self.not_valid_after = not_valid_after
+        self.not_valid_before = not_valid_before
+        self.user_urn = user_urn
+
+
 class SSLClientCertAdapter(HTTPAdapter):
     def __init__(self, certfile: str, keyfile: str, password: Optional[str] = None,
                  server_self_signed_cert: Optional[str] = None, max_retries: Optional[Retry] = None):
@@ -91,6 +102,26 @@ class GpuLabApiClient(object):
         assert os.path.isfile(certfile), "certfile '{}' not found".format(certfile)
         assert os.path.isfile(keyfile), "keyfile '{}' not found".format(keyfile)
 
+        cert_info = process_cert(certfile)
+        self.user_urn = cert_info.subject_user_urn
+        self.username = cert_info.subject_username
+        now = datetime_now()
+        if cert_info.not_valid_after < now:
+            # f'ERROR: The certificate in your login PEM has expired. '
+            # f'Try to re-download it from the portal. '
+            # f'cert.not_valid_before={cert_info.not_valid_before} '
+            # f'cert.not_valid_after={cert_info.not_valid_after} '
+            raise CertExpiredException(not_valid_before=cert_info.not_valid_before,
+                                       not_valid_after=cert_info.not_valid_after,
+                                       user_urn=self.user_urn)
+        if cert_info.not_valid_before > now:
+            raise ValueError(f'ERROR: The certificate in your login PEM is not yet valid.'
+                             f'cert.not_valid_before={cert_info.not_valid_before} '
+                             f'cert.not_valid_after={cert_info.not_valid_after} ')
+
+        if cert_info.subject_user_urn.startswith('urn:publicid:IDN+wall2.ilabt.iminds.be+user+'):
+            raise LegacyAuthException()
+
         self.dev = dev
         if master_base_url:
             assert 'api/gpulab/v1.0' not in master_base_url
@@ -121,20 +152,6 @@ class GpuLabApiClient(object):
         session.headers.update({'User-Agent': ' '.join([GPULAB_API_CLIENT_USER_AGENT_BASE, default_user_agent()])})
         self.session = session
 
-        cert_info = process_cert(certfile)
-        self.user_urn = cert_info.subject_user_urn
-        self.username = cert_info.subject_username
-        now = datetime_now()
-        if cert_info.not_valid_after < now:
-            raise ValueError(f'ERROR: The certificate in your login PEM has expired. '
-                             f'Try to re-download it from the portal. '
-                             f'cert.not_valid_before={cert_info.not_valid_before} '
-                             f'cert.not_valid_after={cert_info.not_valid_after} ')
-        if cert_info.not_valid_before > now:
-            raise ValueError(f'ERROR: The certificate in your login PEM is not yet valid.'
-                             f'cert.not_valid_before={cert_info.not_valid_before} '
-                             f'cert.not_valid_after={cert_info.not_valid_after} ')
-
     def get_base_url(self):
         if self.master_base_url:
             return self.master_base_url
